Module normalize_interval::selection

source ·
Provides a set of possibly noncontiguous intervals.

Structs

  • An Iterator over the Intervals of a Selection.
  • An owning Iterator over the Intervals of a Selection.
  • An owning Iterator over the points of a Selection.
  • An Iterator over the points of a Selection.
  • A possibly noncontiguous collection of Intervals of the type T.